@@ -33,6 +33,14 @@ config.suffixes = ['.test']
 config.ptxas = which('ptxas')
 
 
+# <https://pubs.opengroup.org/onlinepubs/9699919799/basedefs/V1_chap08.html#tag_08_03>
+# states that "If 'PATH' is unset or is set to null, the path search is
+# implementation-defined."  To avoid that, and to avoid any potentially
+# undefined behavior when pointing to a non-existing directory, set up 'PATH'
+# pointing to a directory that doesn't contain any meaningful executable files.
+config.substitutions.append(('%empty_path', 'PATH=' + config.test_source_root))
+
+
 config.substitutions.append(('%target_ar_cmd', config.target_ar))
 
 
